==> 1.7.2.zip: ufw-tools/README.md <==
LICENSE
=======
All scripts here are released uder the ISC permissive free software license (http://en.wikipedia.org/wiki/ISC_license).
It basically says that you can do whatever you like with the code as long as you credit the author and provide the license with it.
Also see LICENSE in the repo.

Support
=======
I do not promise any support for any of the provided scripts. That said, I'll do what I can for you if I'm not too busy and/or drunk.

General information
===================
The paths are all configurable of course.
The help information that the scripts give is dynamic and is provided here only for reference.

Scripts
=======

sup
---
A very simple tool to upload files to the zfh.so file hosting

	Usage: sup [-RsF] [-D num] [file/url]"
	Flags:
	    -R                   # Remove the file after uploading.
	    -s                   # Make a screenshot and upload it instead of a file.
	    -F                   # Make a fullscreen shot instead of prompting for a window/area. Implies -s.
	    -D <num>             # Delay the shot by <num> seconds.
	    -p                   # Make the file private. Requires $secret to be set in the config.
	    -m                   # Maximum filesize (takes K, M and G suffixes).

	Config options (~/.suprc):
	    secret               # Your personal token. Get it at https://zfh.so/settings_form
	    cfg_screenshot_ext   # Screenshot file type, used by scrot.
	    # Others are self-explanatory:
	    cfg_url_regex
	    cfg_tmp_dir
	    cfg_script_url

==> 1.9.3.zip: ufw-tools/README.md <==
LICENSE
=======
All scripts here are released uder the ISC permissive free software license (http://en.wikipedia.org/wiki/ISC_license).
It basically says that you can do whatever you like with the code as long as you credit the author and provide the license with it.
Also see LICENSE in the repo.

Support
=======
I do not promise any support for any of the provided scripts. That said, I'll do what I can for you if I'm not too busy and/or drunk.

General information
===================
The paths are all configurable of course.
The help information that the scripts give is dynamic and is provided here only for reference.

Scripts
=======

ufw
---
A very simple tool to upload files to the zfh.so file hosting

	Usage: ufw [-RsF] [-D num] [file/url]"
	Flags:
	    -R                   # Remove the file after uploading.
	    -s                   # Make a screenshot and upload it instead of a file.
	    -F                   # Make a fullscreen shot instead of prompting for a window/area. Implies -s.
	    -D <num>             # Delay the shot by <num> seconds.
	    -p                   # Make the file private. Requires $secret to be set in the config.
	    -m                   # Maximum filesize (takes K, M and G suffixes).

	Config options (~/.config/ufw):
	    secret               # Your personal token. Get it at https://zfh.so/settings_form
	    cfg_screenshot_ext   # Screenshot file type, used by scrot.
	    # Others are self-explanatory:
	    cfg_url_regex
	    cfg_tmp_dir
	    cfg_script_url
